@@ -10,11 +10,11 @@ Pg::Explain::FromJSON - Parser for explains in JSON format
 
 =head1 VERSION
 
-Version 0.80
+Version 0.81
 
 =cut
 
-our $VERSION = '0.80';
+our $VERSION = '0.81';
 
 =head1 SYNOPSIS
 
@@ -39,20 +39,25 @@ sub parse_source {
     # We need to remove things before and/or after explain
     # To do this, first - split explain into lines...
     my @source_lines = split( /[\r\n]+/, $source );
-    my $prefix = '';
 
-    # Now, find first line of explain, and cache it's prefix (some spaces ...)
-    for my $l ( @source_lines ) {
-        next unless $l =~ m{\A (\s*) \[ \s* \z }x;
-        $prefix = $1;
+    if ( 1 < scalar @source_lines ) {
+
+        # If there are many lines, there could be line prefix...
+        my $prefix = '';
+
+        # Now, find first line of explain, and cache it's prefix (some spaces ...)
+        for my $l ( @source_lines ) {
+            next unless $l =~ m{\A (\s*) \[ \s* \z }x;
+            $prefix = $1;
+        }
+
+        # Now, extract lines with explain using known prefix
+        my @use_lines = grep { /\A$prefix\[\s*\z/ .. /\A$prefix\]\s*\z/ } @source_lines;
+        $source = join( "\n", @use_lines );
     }
 
-    # Now, extract lines with explain using known prefix
-    my @use_lines = grep { /\A$prefix\[\s*\z/ .. /\A$prefix\]\s*\z/ } @source_lines;
-    my $use_source = join( "\n", @use_lines );
-
     # And now parse the json...
-    my $struct = from_json( $use_source );
+    my $struct = from_json( $source );
 
     my $top_node = $self->make_node_from( $struct->[ 0 ]->{ 'Plan' } );
 
